import { ViewMessage } from '@/interface/message';
import EntityService from '@/service/entity-service';

/**
 * 视图消息
 *
 * @export
 * @class ViewMessage
 */
export default class ViewMessageService {

    /**
     * 单例变量声明
     *
     * @private
     * @static
     * @type {ViewMessageService}
     * @memberof ViewMessageService
     */
    private static ViewMessage: ViewMessageService;

    /**
     * 实体数据服务对象
     *
     * @protected
     * @type {EntityService}
     * @memberof ViewMessageService
     */
    protected entityService:EntityService = new EntityService();

    /**
     * 视图消息标识
     *
     * @type {string}
     * @memberof ViewMessageService
     */
    public id:string ="";

    /**
     * 视图消息名称
     *
     * @type {string}
     * @memberof ViewMessageService
     */
    public name:string ="";

    /**
     * 视图消息代码名称
     *
     * @type {string}
     * @memberof ViewMessageService
     */
    public codename:string ="";

    /**
     * 视图消息标题
     *
     * @type {string}
     * @memberof ViewMessageService
     */
    public tilte:string ="";

    /**
     * 视图消息内容
     *
     * @type {string}
     * @memberof ViewMessageService
     */
    public content:string ="";

    /**
     * 视图消息关闭模式
     *
     * @type {string}
     * @memberof ViewMessageService
     */
    public closeMode:string ="";

    /**
     * 视图消息位置
     *
     * @type {string}
     * @memberof ViewMessageService
     */
    public position:string ="";

    /**
     * 视图消息类型
     *
     * @type {string}
     * @memberof ViewMessageService
     */
    public type:string = "";

    /**
     * 是否默认视图消息
     *
     * @type {boolean}
     * @memberof ViewMessageService
     */
    public isdefault:boolean = true;

    /**
     * 视图消息是否支持删除
     *
     * @type {boolean}
     * @memberof ViewMessageService
     */
    public isEnableRemove:boolean = true;

    /**
     * 动态模式
     *
     * @type {string}
     * @memberof ViewMessageService
     */
    public dynamicMode:string = "STATIC";

    /**
     * 初始化实例
     * 
     * @memberof ViewMessageService
     */
    constructor(opts: any = {}) {
        this.initBasicParam();
    }

    /**
     * 获取 ViewMessageService 单例对象
     *
     * @static
     * @returns {ViewMessageService}
     * @memberof ViewMessageService
     */
    public static getInstance(): ViewMessageService {
        if (!ViewMessageService.ViewMessage) {
            ViewMessageService.ViewMessage = new ViewMessageService();
        }
        return this.ViewMessage;
    }

    /**
     * 初始化基础参数
     * 
     * @memberof ViewMessageService
     */
    public initBasicParam(){}

    /**
     * 获取视图消息服务
     *
     * @protected
     * @param {string} name 视图消息codename
     * @returns {Promise<any>}
     * @memberof ViewMessageService
     */
    public getService(name: string): Promise<any> {
        return (window as any)['messageServiceRegister'].getService(name);
    }

    /**
     * 通过tag获取视图消息
     * 
     * @param {tag:string} 视图消息标识
     * @param {context:any} 导航上下文
     * @param {viewparam:any} 导航参数
     * @memberof ViewMessageService
     */
    public async getViewMessageByTag(tag:string,context:any,viewparam:any){
        let messageService:any = await this.getService(tag);
        if(messageService.dynamicMode && Object.is(messageService.dynamicMode,"STATIC")){
            return messageService.getStaticViewMessage();
        }
    }

    /**
     * 获取动态模式（静态）类型视图消息
     * 
     * @memberof ViewMessageService
     */
    public getStaticViewMessage():Array<ViewMessage>{
        let returnViewMessage:ViewMessage ={
            id:this.id,
            name:this.name,
            codename:this.codename,
            tilte:this.tilte,
            content:this.content,
            closeMode:this.closeMode,
            position:this.position,
            type:this.type,
            isdefault:this.isdefault,
            isEnableRemove:this.isEnableRemove,
            dynamicMode:this.dynamicMode
        };
        return [returnViewMessage];
    }

    /**
     * 获取动态模式（实体数据集合）类型视图消息
     * 
     * @memberof ViewMessageService
     */
    public async getDynamicViewMessage():Promise<Array<ViewMessage>>{
        return [];
    }
    

}